About This Project
==================

License
-------

.. container:: license

    | Copyright © 2010-2011, `Dag Odenhall <dag.odenhall@gmail.com>`_ and
      :ref:`contributors <authors>`
    | All rights reserved.

    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are met:

    * Redistributions of source code must retain the above copyright notice,
      this list of conditions and the following disclaimer.

    * Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation
      and/or other materials provided with the distribution.

.. container:: small-caps

    This software is provided by the copyright holders and contributors "as
    is" and any express or implied warranties, including, but not limited
    to, the implied warranties of merchantability and fitness for a
    particular purpose are disclaimed. In no event shall the copyright
    holder or contributors be liable for any direct, indirect, incidental,
    special, exemplary, or consequential damages (including, but not
    limited to, procurement of substitute goods or services; loss of use,
    data, or profits; or business interruption) however caused and on any
    theory of liability, whether in contract, strict liability, or tort
    (including negligence or otherwise) arising in any way out of the use
    of this software, even if advised of the possibility of such damage.


.. _authors:

Authors
-------

.. include:: ../AUTHORS.rst


Community
---------

The Attest IRC channel is `#pocoo on irc.freenode.net
<http://bit.ly/pocooirc>`_. Attest shares that channel with other Pocoo
projects, so please let others know that you are talking about Attest
when asking a question.

If you prefer discussions or support via e-mail you can use the `pocoo-libs
mailinglist <http://groups.google.com/group/pocoo-libs>`_.

If neither IRC or e-mail is for you, as an experiment we're trying out
Convore `for a web-based support forum <https://convore.com/attest/>`_.
